@@ -34,7 +34,26 @@ def do_path(cmd, values):
             deprecated = False
             deprecated_date = ''
             deprecated_already = False
-        v = {'action': action.upper(), 'cmd': cmd, 'deprecated': deprecated, 'deprecated_date': deprecated_date, 'deprecated_already': deprecated_already}
+
+        # The requestBody/content could be one of the following:
+        # "requestBody": {
+        #   "content": {
+        #     "application/javascript" {
+        #     "application/json" {
+        #     "application/octet-stream" {
+        #     "application/x-ndjson" {
+        #     "multipart/form-data" {
+
+        content_type = None
+        if 'requestBody' in values[action] and values[action]['requestBody']:
+            request_body = values[action]['requestBody']
+            if 'content' in request_body and request_body['content']:
+                content_type = ','.join(list(request_body['content'].keys()))
+
+        if content_type:
+            v = {'action': action.upper(), 'cmd': cmd, 'deprecated': deprecated, 'deprecated_date': deprecated_date, 'deprecated_already': deprecated_already, 'content_type': content_type}
+        else:
+            v = {'action': action.upper(), 'cmd': cmd, 'deprecated': deprecated, 'deprecated_date': deprecated_date, 'deprecated_already': deprecated_already}
         cmds.append(v)
     return cmds
 
@@ -43,21 +62,18 @@ def api_decode_from_openapi(content):
 
     try:
         j = json.loads(content)
-    except Exception as e:
-        sys.stderr.write("OpenAPI json format issue: %s\n" % (e))
-        return None
+    except json.decoder.JSONDecodeError as e:
+        raise SyntaxError('OpenAPI json decode failed: %s' % (e))
 
     try:
         components = j['components']
         info = j['info']
-        openapi = j['openapi']
+        cloudflare_version = info['version']
+        openapi_version = j['openapi']
         paths = j['paths']
         servers = ['servers']
     except Exception as e:
-        sys.stderr.write("OpenAPI json format structure: %s\n" % (e))
-        return None
-
-    sys.stderr.write("OpenAPI %s json file - version: %s\n" % (openapi, info['version']))
+        raise SyntaxError('OpenAPI json missing standard OpenAPI values: %s' % (e))
 
     all_cmds = []
     for path in paths:
@@ -66,4 +82,4 @@ def api_decode_from_openapi(content):
             continue
         all_cmds += do_path(path, paths[path])
 
-    return sorted(all_cmds, key=lambda v: v['cmd'])
+    return sorted(all_cmds, key=lambda v: v['cmd']), openapi_version, cloudflare_version
