@@ -48,6 +48,9 @@ def api_v4(self):
     # The API commands for /ips/
     ips(self)
 
+    # The API commands for /live/
+    live(self)
+
     # The API commands for /accounts/
     accounts(self)
     accounts_access(self)
@@ -107,7 +110,7 @@ def zones(self):
     self.add('AUTH', 'zones', 'custom_pages')
     self.add('AUTH', 'zones', 'dns_records')
     self.add('AUTH', 'zones', 'dns_records/export')
-    self.add('AUTH', 'zones', 'dns_records/import')
+    self.add('AUTH', 'zones', 'dns_records/import', content_type={'POST':'multipart/form-data'})
     self.add('AUTH', 'zones', 'dns_records/scan')
     self.add('VOID', 'zones', 'dns_settings')
     self.add('AUTH', 'zones', 'dns_settings/use_apex_ns')
@@ -182,6 +185,15 @@ def zones_settings(self):
     self.add('AUTH', 'zones', 'settings/waf')
     self.add('AUTH', 'zones', 'settings/webp')
     self.add('AUTH', 'zones', 'settings/websockets')
+    self.add('VOID', 'zones', 'settings/zaraz')
+    self.add('VOID', 'zones', 'settings/zaraz/v2')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/config')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/default')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/export')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/history')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/history/configs')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/publish')
+    self.add('AUTH', 'zones', 'settings/zaraz/v2/workflow')
 
 def zones_analytics(self):
     """ zones analytics """
@@ -250,7 +262,7 @@ def zones_logs(self):
     self.add('VOID', 'zones', 'logs/control/retention')
     self.add('AUTH', 'zones', 'logs/control/retention/flag')
     self.add('AUTH_UNWRAPPED', 'zones', 'logs/received')
-    self.add('AUTH_UNWRAPPED', 'zones', 'logs/received/fields')
+    self.add('AUTH', 'zones', 'logs/received/fields')
     self.add('AUTH_UNWRAPPED', 'zones', 'logs/rayids')
 
 def railguns(self):
@@ -269,6 +281,11 @@ def ips(self):
 
     self.add('OPEN', 'ips')
 
+def live(self):
+    """ live """
+
+    self.add('AUTH', 'live')
+
 def zones_argo(self):
     """ zones argo """
 
@@ -390,12 +407,15 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'custom_pages')
 
     self.add('VOID', 'accounts', 'dlp')
+    self.add('AUTH', 'accounts', 'dlp/datasets')
+    self.add('AUTH', 'accounts', 'dlp/datasets', 'upload', content_type={'POST':'application/octet-stream'})
     self.add('VOID', 'accounts', 'dlp/patterns')
     self.add('AUTH', 'accounts', 'dlp/patterns/validate')
     self.add('AUTH', 'accounts', 'dlp/payload_log')
     self.add('AUTH', 'accounts', 'dlp/profiles')
     self.add('AUTH', 'accounts', 'dlp/profiles/custom')
     self.add('AUTH', 'accounts', 'dlp/profiles/predefined')
+
     self.add('AUTH', 'accounts', 'members')
     self.add('VOID', 'accounts', 'mnm')
     self.add('AUTH', 'accounts', 'mnm/config')
@@ -437,7 +457,7 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'storage/kv/namespaces')
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'bulk')
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'keys')
-    self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'values')
+    self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'values', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'storage/kv/namespaces', 'metadata')
 
     self.add('AUTH', 'accounts', 'subscriptions')
@@ -447,6 +467,9 @@ def accounts(self):
     self.add('VOID', 'accounts', 'vectorize')
     self.add('AUTH', 'accounts', 'vectorize/index')
     self.add('AUTH', 'accounts', 'vectorize/indexes')
+    self.add('AUTH', 'accounts', 'vectorize/indexes', 'insert', content_type={'POST':'application/x-ndjson'})
+    self.add('AUTH', 'accounts', 'vectorize/indexes', 'query')
+    self.add('AUTH', 'accounts', 'vectorize/indexes', 'upsert', content_type={'POST':'application/x-ndjson'})
 
     self.add('AUTH', 'accounts', 'virtual_dns')
     self.add('VOID', 'accounts', 'virtual_dns', 'dns_analytics')
@@ -461,7 +484,7 @@ def accounts(self):
     self.add('VOID', 'accounts', 'workers/dispatch')
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces')
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts')
-    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'content')
+    self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'content', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'settings')
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts', 'tags')
     self.add('AUTH', 'accounts', 'workers/domains')
@@ -471,15 +494,15 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'workers/queues')
     self.add('AUTH', 'accounts', 'workers/queues', 'consumers')
     self.add('AUTH', 'accounts', 'workers/scripts')
-    self.add('AUTH', 'accounts', 'workers/scripts', 'content')
+    self.add('AUTH', 'accounts', 'workers/scripts', 'content', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'workers/scripts', 'content/v2')
     self.add('AUTH', 'accounts', 'workers/scripts', 'schedules')
-    self.add('AUTH', 'accounts', 'workers/scripts', 'settings')
+    self.add('AUTH', 'accounts', 'workers/scripts', 'settings', content_type={'PATCH':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'workers/scripts', 'tails')
     self.add('AUTH', 'accounts', 'workers/scripts', 'usage-model')
     self.add('VOID', 'accounts', 'workers/services')
     self.add('VOID', 'accounts', 'workers/services', 'environments')
-    self.add('AUTH', 'accounts', 'workers/services', 'environments', 'content')
+    self.add('AUTH', 'accounts', 'workers/services', 'environments', 'content', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'workers/services', 'environments', 'settings')
     self.add('AUTH', 'accounts', 'workers/subdomain')
 
@@ -491,7 +514,7 @@ def accounts_addressing(self):
     self.add('AUTH', 'accounts', 'addressing/address_maps', 'accounts')
     self.add('AUTH', 'accounts', 'addressing/address_maps', 'ips')
     self.add('AUTH', 'accounts', 'addressing/address_maps', 'zones')
-    self.add('AUTH', 'accounts', 'addressing/loa_documents')
+    self.add('AUTH', 'accounts', 'addressing/loa_documents', content_type={'POST':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'addressing/loa_documents', 'download')
     self.add('AUTH', 'accounts', 'addressing/prefixes')
     self.add('VOID', 'accounts', 'addressing/prefixes', 'bgp')
@@ -545,7 +568,7 @@ def accounts_stream(self):
     self.add('AUTH', 'accounts', 'stream')
     self.add('AUTH', 'accounts', 'stream', 'audio')
     self.add('AUTH', 'accounts', 'stream', 'audio/copy')
-    self.add('AUTH', 'accounts', 'stream', 'captions')
+    self.add('AUTH', 'accounts', 'stream', 'captions', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'stream', 'embed')
     self.add('AUTH', 'accounts', 'stream', 'downloads')
     self.add('AUTH', 'accounts', 'stream', 'token')
@@ -554,7 +577,7 @@ def accounts_stream(self):
     self.add('AUTH', 'accounts', 'stream/direct_upload')
     self.add('AUTH', 'accounts', 'stream/keys')
 #   self.add('AUTH', 'accounts', 'stream/preview')
-    self.add('AUTH', 'accounts', 'stream/watermarks')
+    self.add('AUTH', 'accounts', 'stream/watermarks', content_type={'POST':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'stream/webhook')
     self.add('AUTH', 'accounts', 'stream/live_inputs')
     self.add('AUTH', 'accounts', 'stream/live_inputs', 'outputs')
@@ -624,8 +647,12 @@ def accounts_access(self):
     self.add('VOID', 'accounts', 'access/logs')
     self.add('AUTH', 'accounts', 'access/logs/access_requests')
     self.add('AUTH', 'accounts', 'access/seats')
+    self.add('AUTH', 'accounts', 'access/tags')
     self.add('AUTH', 'accounts', 'access/users')
     self.add('AUTH', 'accounts', 'access/users', 'failed_logins')
+    self.add('AUTH', 'accounts', 'access/users', 'active_sessions')
+    self.add('AUTH', 'accounts', 'access/users', 'last_seen_identity')
+
 
 def accounts_diagnostics(self):
     """ accounts diagnostics """
@@ -647,12 +674,17 @@ def zones_waiting_rooms(self):
 def accounts_extras(self):
     """ extras """
 
+    self.add('VOID', 'accounts', 'ai')
+    self.add('AUTH', 'accounts', 'ai/run', content_type={'POST':['application/json','application/octet-stream']})
+    self.add('AUTH', 'accounts', 'ai/run/proxy')
+
     self.add('VOID', 'accounts', 'alerting')
     self.add('VOID', 'accounts', 'alerting/v3')
     self.add('AUTH', 'accounts', 'alerting/v3/available_alerts')
     self.add('VOID', 'accounts', 'alerting/v3/destinations')
     self.add('AUTH', 'accounts', 'alerting/v3/destinations/eligible')
     self.add('AUTH', 'accounts', 'alerting/v3/destinations/pagerduty')
+    self.add('AUTH', 'accounts', 'alerting/v3/destinations/pagerduty/connect')
     self.add('AUTH', 'accounts', 'alerting/v3/destinations/webhooks')
     self.add('AUTH', 'accounts', 'alerting/v3/history')
     self.add('AUTH', 'accounts', 'alerting/v3/policies')
@@ -682,13 +714,19 @@ def accounts_extras(self):
 
     self.add('VOID', 'accounts', 'dex')
     self.add('AUTH', 'accounts', 'dex/colos')
+    self.add('VOID', 'accounts', 'dex/fleet-status')
+    self.add('AUTH', 'accounts', 'dex/fleet-status/devices')
+    self.add('AUTH', 'accounts', 'dex/fleet-status/live')
+    self.add('AUTH', 'accounts', 'dex/fleet-status/over-time')
     self.add('AUTH', 'accounts', 'dex/http-tests')
+    self.add('AUTH', 'accounts', 'dex/http-tests', 'percentiles')
     self.add('AUTH', 'accounts', 'dex/tests')
     self.add('AUTH', 'accounts', 'dex/tests/unique-devices')
     self.add('VOID', 'accounts', 'dex/traceroute-test-results')
     self.add('AUTH', 'accounts', 'dex/traceroute-test-results', 'network-path')
     self.add('AUTH', 'accounts', 'dex/traceroute-tests')
     self.add('AUTH', 'accounts', 'dex/traceroute-tests', 'network-path')
+    self.add('AUTH', 'accounts', 'dex/traceroute-tests', 'percentiles')
 
     self.add('AUTH', 'accounts', 'dns_firewall')
     self.add('VOID', 'accounts', 'dns_firewall', 'dns_analytics')
@@ -697,6 +735,7 @@ def accounts_extras(self):
 
     self.add('AUTH', 'accounts', 'gateway')
     self.add('AUTH', 'accounts', 'gateway/app_types')
+    self.add('AUTH', 'accounts', 'gateway/audit_ssh_settings')
     self.add('AUTH', 'accounts', 'gateway/categories')
     self.add('AUTH', 'accounts', 'gateway/configuration')
     self.add('AUTH', 'accounts', 'gateway/lists')
@@ -707,14 +746,14 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'gateway/rules')
 
     self.add('VOID', 'accounts', 'images')
-    self.add('AUTH', 'accounts', 'images/v1')
+    self.add('AUTH', 'accounts', 'images/v1', content_type={'POST':'multipart/form-data'})
     self.add('AUTH', 'accounts', 'images/v1', 'blob')
     self.add('AUTH', 'accounts', 'images/v1/config')
     self.add('AUTH', 'accounts', 'images/v1/keys')
     self.add('AUTH', 'accounts', 'images/v1/stats')
     self.add('AUTH', 'accounts', 'images/v1/variants')
     self.add('AUTH', 'accounts', 'images/v2')
-    self.add('AUTH', 'accounts', 'images/v2/direct_upload')
+    self.add('AUTH', 'accounts', 'images/v2/direct_upload', content_type={'POST':'multipart/form-data'})
 
     self.add('VOID', 'accounts', 'intel')
     self.add('VOID', 'accounts', 'intel-phishing')
@@ -727,7 +766,7 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'intel/domain/bulk')
     self.add('AUTH', 'accounts', 'intel/indicator-feeds')
     self.add('AUTH', 'accounts', 'intel/indicator-feeds', 'data')
-    self.add('AUTH', 'accounts', 'intel/indicator-feeds', 'snapshot')
+    self.add('AUTH', 'accounts', 'intel/indicator-feeds', 'snapshot', content_type={'PUT':'multipart/form-data'})
     self.add('VOID', 'accounts', 'intel/indicator-feeds/permissions')
     self.add('AUTH', 'accounts', 'intel/indicator-feeds/permissions/add')
     self.add('AUTH', 'accounts', 'intel/indicator-feeds/permissions/remove')
@@ -746,7 +785,7 @@ def accounts_extras(self):
 
     self.add('VOID', 'accounts', 'pages')
     self.add('AUTH', 'accounts', 'pages/projects')
-    self.add('AUTH', 'accounts', 'pages/projects', 'deployments')
+    self.add('AUTH', 'accounts', 'pages/projects', 'deployments', content_type={'POST':'multipart/form-data'})
     self.add('VOID', 'accounts', 'pages/projects', 'deployments', 'history')
     self.add('AUTH', 'accounts', 'pages/projects', 'deployments', 'history/logs')
     self.add('AUTH', 'accounts', 'pages/projects', 'deployments', 'retry')
@@ -773,17 +812,30 @@ def accounts_extras(self):
     self.add('VOID', 'accounts', 'hyperdrive')
     self.add('AUTH', 'accounts', 'hyperdrive/configs')
 
+    self.add('AUTH', 'accounts', 'warp_connector')
+    self.add('AUTH', 'accounts', 'warp_connector', 'token')
+
+    self.add('VOID', 'accounts', 'zerotrust')
+    self.add('AUTH', 'accounts', 'zerotrust/connectivity_settings')
+
+    self.add('VOID', 'accounts', 'd1')
+    self.add('AUTH', 'accounts', 'd1/database')
+    self.add('AUTH', 'accounts', 'd1/database', 'query')
 
 def zones_extras(self):
     """ zones extras """
 
     self.add('VOID', 'zones', 'acm')
     self.add('AUTH', 'zones', 'acm/total_tls')
+
     self.add('VOID', 'zones', 'cache')
-    self.add('AUTH', 'zones', 'cache/variants')
     self.add('AUTH', 'zones', 'cache/cache_reserve')
+    self.add('AUTH', 'zones', 'cache/cache_reserve_clear')
+    self.add('AUTH', 'zones', 'cache/origin_post_quantum_encryption')
     self.add('AUTH', 'zones', 'cache/regional_tiered_cache')
     self.add('AUTH', 'zones', 'cache/tiered_cache_smart_topology_enable')
+    self.add('AUTH', 'zones', 'cache/variants')
+
     self.add('AUTH', 'zones', 'managed_headers')
     self.add('AUTH', 'zones', 'page_shield')
     self.add('AUTH', 'zones', 'page_shield/policies')
@@ -802,7 +854,7 @@ def zones_extras(self):
 
     self.add('VOID', 'zones', 'hostnames')
     self.add('AUTH', 'zones', 'hostnames/settings')
-    self.add('AUTH', 'zones', 'snippets')
+    self.add('AUTH', 'zones', 'snippets', content_type={'PUT':'multipart/form-data'})
     self.add('AUTH', 'zones', 'snippets', 'content')
     self.add('AUTH', 'zones', 'snippets/snippet_rules')
 
@@ -857,8 +909,16 @@ def zones_api_gateway(self):
     self.add('VOID', 'zones', 'api_gateway')
     self.add('AUTH', 'zones', 'api_gateway/configuration')
     self.add('AUTH', 'zones', 'api_gateway/discovery')
+    self.add('AUTH', 'zones', 'api_gateway/discovery/operations')
     self.add('AUTH', 'zones', 'api_gateway/operations')
+    self.add('AUTH', 'zones', 'api_gateway/operations', 'schema_validation')
+#   self.add('AUTH', 'zones', 'api_gateway/operations/schema_validation')
     self.add('AUTH', 'zones', 'api_gateway/schemas')
+    self.add('VOID', 'zones', 'api_gateway/settings')
+    self.add('AUTH', 'zones', 'api_gateway/settings/schema_validation')
+    self.add('AUTH', 'zones', 'api_gateway/user_schemas', content_type={'POST':'multipart/form-data'})
+    self.add('AUTH', 'zones', 'api_gateway/user_schemas', 'operations')
+
 
 def radar(self):
     """ radar """
@@ -919,20 +979,38 @@ def radar(self):
     self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/vector')
     self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/vertical')
     self.add('VOID', 'radar/attacks/layer3/top')
+    self.add('AUTH', 'radar/attacks/layer3/top/attacks')
     self.add('AUTH', 'radar/attacks/layer3/top/industry')
+    self.add('VOID', 'radar/attacks/layer3/top/locations')
+    self.add('AUTH', 'radar/attacks/layer3/top/locations/origin')
+    self.add('AUTH', 'radar/attacks/layer3/top/locations/target')
     self.add('AUTH', 'radar/attacks/layer3/top/vertical')
 
     self.add('VOID', 'radar/attacks/layer7')
     self.add('AUTH', 'radar/attacks/layer7/summary')
+    self.add('AUTH', 'radar/attacks/layer7/summary/http_method')
+    self.add('AUTH', 'radar/attacks/layer7/summary/http_version')
+    self.add('AUTH', 'radar/attacks/layer7/summary/ip_version')
+    self.add('AUTH', 'radar/attacks/layer7/summary/managed_rules')
+    self.add('AUTH', 'radar/attacks/layer7/summary/mitigation_product')
     self.add('AUTH', 'radar/attacks/layer7/timeseries')
     self.add('AUTH', 'radar/attacks/layer7/timeseries_groups')
+    self.add('AUTH', 'radar/attacks/layer7/timeseries_groups/http_method')
+    self.add('AUTH', 'radar/attacks/layer7/timeseries_groups/http_version')
+    self.add('AUTH', 'radar/attacks/layer7/timeseries_groups/industry')
+    self.add('AUTH', 'radar/attacks/layer7/timeseries_groups/ip_version')
+    self.add('AUTH', 'radar/attacks/layer7/timeseries_groups/managed_rules')
+    self.add('AUTH', 'radar/attacks/layer7/timeseries_groups/mitigation_product')
+    self.add('AUTH', 'radar/attacks/layer7/timeseries_groups/vertical')
     self.add('VOID', 'radar/attacks/layer7/top')
     self.add('VOID', 'radar/attacks/layer7/top/ases')
     self.add('AUTH', 'radar/attacks/layer7/top/ases/origin')
     self.add('AUTH', 'radar/attacks/layer7/top/attacks')
+    self.add('AUTH', 'radar/attacks/layer7/top/industry')
     self.add('VOID', 'radar/attacks/layer7/top/locations')
     self.add('AUTH', 'radar/attacks/layer7/top/locations/origin')
     self.add('AUTH', 'radar/attacks/layer7/top/locations/target')
+    self.add('AUTH', 'radar/attacks/layer7/top/vertical')
 
     self.add('VOID', 'radar/bgp')
     self.add('VOID', 'radar/bgp/leaks')
@@ -1102,6 +1180,7 @@ def radar(self):
     self.add('AUTH', 'radar/traffic_anomalies')
     self.add('AUTH', 'radar/traffic_anomalies/locations')
 
+
 def from_developers(self):
     """ from_developers """
     self.add('VOID', 'accounts', 'analytics_engine')
